#include <stdbool.h>
#include <stdint.h>
#include "nrf_delay.h"
#include "boards.h"


int main(void)
{
    /* Configure board. */
    bsp_board_init(BSP_INIT_LEDS);
    bsp_board_leds_off();

    /* Configure wakeup pin */
    nrf_gpio_cfg_sense_input(BSP_BUTTON_0, NRF_GPIO_PIN_PULLUP, NRF_GPIO_PIN_SENSE_LOW);

    if (NRF_POWER->RESETREAS & POWER_RESETREAS_RESETPIN_Msk)
    {
        NRF_POWER->RESETREAS = ~POWER_RESETREAS_RESETPIN_Msk;
    }

    if(NRF_POWER->RESETREAS & POWER_RESETREAS_RESETPIN_Msk)
    {
        // Light LED 1 to indicate pin reset
        bsp_board_led_on(0);
    }
    else if (NRF_POWER->RESETREAS == 0)
    {
        // Light LED 2 to indicate power on or brown out reset
        bsp_board_led_on(1);

        // Check if wake-up button is also pressed (even if we woke up due to power on reset)
        if(nrf_gpio_pin_read(BSP_BUTTON_0) == 0)
        {
            // Wake up from power on reset *AND* wakeup button is pushed. This is were we enter DFU mdoe!
            // Light LED 3 as well to indicate GPIO pin is pressed.
            bsp_board_led_on(2);
        }
    }
    else if (NRF_POWER->RESETREAS & POWER_RESETREAS_OFF_Msk)
    {
        // Light LED 3 to indicate wakeup from GPIO (without power cycle)
        bsp_board_led_on(2);
    }
    else
    {
        // Light LED 4 to indicate other wakeup reason
        bsp_board_led_on(3);
    }

    // Clear RESETREAS
    NRF_POWER->RESETREAS = ~0;

    // Wait 2 seconds before entering system off.
    // Press reset button or power cycle DK to test different behaviour after that point.
    nrf_delay_ms(2000);
    NRF_POWER->SYSTEMOFF = 1;

    while (true)
    {
        // Should never arrive here
    }
}

